<?php
  if ( ! defined( 'ABSPATH' ) ) exit;
  
  class Fasta_Credit_Utils {
    
    static function load_fasta_checkout_scripts( $fasta_url, $fasta_merchant_id ) {
      $order_pay_checkout_endpoint_slug = get_option( 'woocommerce_checkout_pay_endpoint' );
      
      if( !is_wc_endpoint_url( $order_pay_checkout_endpoint_slug ) ) return;

      global $wp;
      $order_id = $wp->query_vars[ $order_pay_checkout_endpoint_slug ];
      $order = new WC_Order( $order_id );
      
      wp_enqueue_script( 'fasta-checkout-sdk', $fasta_url . '/assets/js/fasta-checkout.js', true );
      wp_register_script( 'fasta_credit_js', plugin_dir_url( __DIR__ ) . 'js/fasta-credit.js', true );
      wp_localize_script( 'fasta_credit_js', 'params', json_encode(self::build_checkout_info( $order, $fasta_merchant_id )), true );
      wp_enqueue_script( 'fasta_credit_js', array( 'fasta-checkout-sdk' ), true );
    }

    static function build_checkout_info( $order, $fasta_merchant_id ) {
      $is_wc_v3 = self::is_wc_3();

      $customer_order_details = $order->get_address();
      $customer = array(
        'name' => $customer_order_details['first_name'],
        'surname' => $customer_order_details['last_name'],
        'email' => $customer_order_details['email'],
        'phone' => $customer_order_details['phone']
      );
      $customer_address = array(
        'contact' => $customer_order_details['address_1'],
        'street' => $customer_order_details['address_2'],
        'city' => $customer_order_details['city'],
        'postalCode' => $customer_order_details['postcode'],
      );

      $products = array();
      foreach( $order->get_items() as $item ) {
        $product_id = $is_wc_v3 ? $item->get_product_id() : $item['product_id'];

        array_push($products, array(
          'id' => $product_id,
          'name' => $item['name'],
          'description' => '',
          'amount' => (float) $item['line_total'],
        ));
      }

      $cart_id = '';
      if( $is_wc_v3 ) {
        $cart_id = $order->get_id();
      } else {
        $cart_id = $order->get_order_number();
      }

      $cart_data = array(
        'cartId' => $cart_id,
        'amount' => $order->get_total(),
        'appId' => $fasta_merchant_id,
        'customer' => $customer,
        'address' => $customer_address,
        'products' => $products,
        'initialLoanNotification' => TRUE,
        'returnUrl' => $order->get_checkout_order_received_url(),
      );

      $hold_stock_minutes = get_option( 'woocommerce_hold_stock_minutes' );
      if($hold_stock_minutes != null) {
        $order_expires_at = new DateTime($is_wc_v3 ? $order->get_date_created() : $order->order_date);
        $order_expires_at->add( new DateInterval( 'PT' . $hold_stock_minutes . 'M' ) );
        $order_expires_at->setTimezone( new DateTimeZone("UTC") );
        $cart_data['cartExpiresAt'] = $order_expires_at;
      }

      return $cart_data;
    }

    static function is_wc_3() {
      global $woocommerce;
      return version_compare( $woocommerce->version, '3.0', '>=' );
    }

    static function build_fasta_merchant_portal_url( string $base_portal_url ) {
      return function ( string $loan_number ) use ( $base_portal_url ) {
        return $loan_number != '' ? "{$base_portal_url}/#/merchant/sales/?id={$loan_number}" : $base_portal_url;
      };
    }
  }
?>